@@ -1,4 +1,4 @@
-setMethod("initialize", "mcprofile", function(.Object, CM, estimate, vest, vestunsc, dvest, model, SRDP, fsplines, bsplines, control, method, ...){
+setMethod("initialize", "mcprofile", function(.Object, CM, estimate, vest, vestunsc, dvest, model, SRDP, fsplines, control, method, ...){
   if (any(class(CM) == "contrMat")) class(CM) <- "matrix" 
   .Object@CM <- CM
   .Object@estimate <- estimate
@@ -8,13 +8,12 @@ setMethod("initialize", "mcprofile", function(.Object, CM, estimate, vest, vestu
   .Object@model <- model
   .Object@SRDP <- SRDP
   .Object@fsplines <- fsplines
-  .Object@bsplines <- bsplines
   .Object@control <- control
   .Object@method <- method
   return(.Object)
 })
 
-setMethod("initialize", "mcprofileRatio", function(.Object, CMn, CMd, estimate, model, SRDP, fsplines, bsplines, control, method, ...){
+setMethod("initialize", "mcprofileRatio", function(.Object, CMn, CMd, estimate, model, SRDP, fsplines, control, method, ...){
   if (any(class(CMn) == "contrMat")) class(CMn) <- "matrix"
   if (any(class(CMd) == "contrMat")) class(CMd) <- "matrix"
   .Object@CMn <- CMn
@@ -23,7 +22,6 @@ setMethod("initialize", "mcprofileRatio", function(.Object, CMn, CMd, estimate,
   .Object@model <- model
   .Object@SRDP <- SRDP
   .Object@fsplines <- fsplines
-  .Object@bsplines <- bsplines
   .Object@control <- control
   .Object@method <- method
   return(.Object)
